"use strict";

// src/delete-old.lambda.ts
var import_client_rds = require("@aws-sdk/client-rds");
var import_client_resource_groups_tagging_api = require("@aws-sdk/client-resource-groups-tagging-api");
var tagging = new import_client_resource_groups_tagging_api.ResourceGroupsTaggingAPIClient();
var rds = new import_client_rds.RDSClient();
exports.handler = async function(input) {
  const snapshotsResponse = await tagging.send(new import_client_resource_groups_tagging_api.GetResourcesCommand({
    TagFilters: input.tags.map((f) => {
      return { Key: f.Key, Values: [f.Value] };
    }),
    ResourceTypeFilters: [input.resourceType]
  }));
  if (!snapshotsResponse.ResourceTagMappingList) {
    console.error("No snapshots found");
  }
  const snapshots = [];
  snapshotsResponse.ResourceTagMappingList.forEach((r) => {
    const id = r.ResourceARN?.split(":").pop();
    if (id) {
      snapshots.push(id);
    } else {
      console.error(`Bad response from tagging API: ${r}`);
    }
  });
  snapshots.sort();
  const toDelete = snapshots.slice(0, -1 * input.historyLimit);
  for (const snapshot of toDelete) {
    console.log(`Deleting old snapshot: ${snapshot}`);
    await rds.send(new import_client_rds.DeleteDBClusterSnapshotCommand({
      DBClusterSnapshotIdentifier: snapshot
    }));
  }
};
