"use strict";

// src/find-snapshot.lambda.ts
var import_client_rds = require("@aws-sdk/client-rds");
var rds = new import_client_rds.RDSClient();
exports.handler = async function(input) {
  let marker = void 0;
  let lastSnapshotId = "";
  let lastSnapshotTime = 0;
  do {
    if (!input.isCluster) {
      const snapshots = await rds.send(new import_client_rds.DescribeDBSnapshotsCommand({
        DBInstanceIdentifier: input.databaseIdentifier,
        Marker: marker
      }));
      for (const snapshot of snapshots.DBSnapshots ?? []) {
        if (snapshot.DBSnapshotIdentifier && snapshot.SnapshotCreateTime && snapshot.SnapshotCreateTime.getTime() > lastSnapshotTime) {
          lastSnapshotTime = snapshot.SnapshotCreateTime.getTime();
          lastSnapshotId = snapshot.DBSnapshotIdentifier;
        }
      }
      marker = snapshots.Marker;
    } else {
      const snapshots = await rds.send(new import_client_rds.DescribeDBClusterSnapshotsCommand({
        DBClusterIdentifier: input.databaseIdentifier,
        Marker: marker
      }));
      for (const snapshot of snapshots.DBClusterSnapshots ?? []) {
        if (snapshot.DBClusterSnapshotIdentifier && snapshot.SnapshotCreateTime && snapshot.SnapshotCreateTime.getTime() > lastSnapshotTime) {
          lastSnapshotTime = snapshot.SnapshotCreateTime.getTime();
          lastSnapshotId = snapshot.DBClusterSnapshotIdentifier;
        }
      }
      marker = snapshots.Marker;
    }
  } while (marker);
  if (lastSnapshotId === "") {
    throw new Error("No snapshots found");
  }
  return {
    id: lastSnapshotId
  };
};
