"use strict";

// src/test-wait.lambda.ts
var import_client_rds = require("@aws-sdk/client-rds");
var import_client_sfn = require("@aws-sdk/client-sfn");
var sfn = new import_client_sfn.SFNClient();
var rds = new import_client_rds.RDSClient();
exports.handler = async function(input) {
  console.log(input.RequestType, input.PhysicalResourceId);
  if (input.RequestType == "Create" || input.RequestType == "Update") {
    const exec = await sfn.send(new import_client_sfn.DescribeExecutionCommand({ executionArn: input.PhysicalResourceId }));
    if (exec.status == "ABORTED" || exec.status == "FAILED" || exec.status == "TIMED_OUT") {
      throw new Error(`Step function failed with: ${exec.status}`);
    }
    if (exec.status == "RUNNING") {
      return { IsComplete: false };
    }
    if (!exec.output) {
      throw new Error("No output?");
    }
    const output = JSON.parse(exec.output);
    if (output.isCluster) {
      const snapshots = await rds.send(new import_client_rds.DescribeDBClusterSnapshotsCommand({ DBClusterSnapshotIdentifier: output.targetSnapshotId }));
      if (!snapshots.DBClusterSnapshots || snapshots.DBClusterSnapshots.length != 1) {
        throw new Error(`Target cluster snapshot ${output.targetSnapshotId} does not exist`);
      }
      await rds.send(new import_client_rds.DeleteDBClusterSnapshotCommand({ DBClusterSnapshotIdentifier: output.targetSnapshotId }));
    } else {
      const snapshots = await rds.send(new import_client_rds.DescribeDBSnapshotsCommand({ DBSnapshotIdentifier: output.targetSnapshotId }));
      if (!snapshots.DBSnapshots || snapshots.DBSnapshots.length != 1) {
        throw new Error(`Target instance snapshot ${output.targetSnapshotId} does not exist`);
      }
      await rds.send(new import_client_rds.DeleteDBSnapshotCommand({ DBSnapshotIdentifier: output.targetSnapshotId }));
    }
    return { IsComplete: true };
  }
  return { IsComplete: true };
};
