"use strict";

// src/wait.lambda.ts
var import_client_rds = require("@aws-sdk/client-rds");
var rds = new import_client_rds.RDSClient();
var NotReady = class extends Error {
  constructor() {
    super("Not ready");
    this.name = "NotReady";
  }
};
function checkStatus(status, source) {
  for (const badStatus of ["stop", "delet", "fail", "incompatible", "inaccessible", "error"]) {
    if (status.indexOf(badStatus) >= 0) {
      throw new Error(`Invalid status ${status} for ${source}`);
    }
  }
  throw new NotReady();
}
function empty(obj) {
  return obj === void 0 || obj === null || Object.keys(obj).length == 0;
}
exports.handler = async function(input) {
  console.log(input);
  if (input.resourceType == "snapshot" && input.snapshotIdentifier) {
    let status;
    if (input.isCluster) {
      const snapshots = await rds.send(new import_client_rds.DescribeDBClusterSnapshotsCommand({
        DBClusterIdentifier: input.databaseIdentifier,
        DBClusterSnapshotIdentifier: input.snapshotIdentifier
      }));
      console.log(snapshots);
      if (!snapshots.DBClusterSnapshots || snapshots.DBClusterSnapshots.length != 1) {
        throw new Error(`Unable to find snapshot ${input.snapshotIdentifier} of ${input.databaseIdentifier}`);
      }
      status = snapshots.DBClusterSnapshots[0].Status ?? "";
    } else {
      const snapshots = await rds.send(new import_client_rds.DescribeDBSnapshotsCommand({
        DBInstanceIdentifier: input.databaseIdentifier,
        DBSnapshotIdentifier: input.snapshotIdentifier
      }));
      console.log(snapshots);
      if (!snapshots.DBSnapshots || snapshots.DBSnapshots.length != 1) {
        throw new Error(`Unable to find snapshot ${input.snapshotIdentifier} of ${input.databaseIdentifier}`);
      }
      status = snapshots.DBSnapshots[0].Status ?? "";
    }
    if (status == "available") {
      return;
    }
    checkStatus(status, input.snapshotIdentifier);
  } else if (input.resourceType == "cluster") {
    const dbs = await rds.send(new import_client_rds.DescribeDBClustersCommand({
      DBClusterIdentifier: input.databaseIdentifier
    }));
    console.log(dbs);
    if (!dbs.DBClusters || dbs.DBClusters.length != 1) {
      throw new Error(`Unable to find db clsuter ${input.databaseIdentifier}`);
    }
    const status = dbs.DBClusters[0].Status ?? "";
    if (status == "available" && empty(dbs.DBClusters[0].PendingModifiedValues)) {
      return;
    }
    checkStatus(status, input.databaseIdentifier);
  } else if (input.resourceType == "instance") {
    const instances = await rds.send(new import_client_rds.DescribeDBInstancesCommand({
      DBInstanceIdentifier: input.databaseIdentifier
    }));
    console.log(instances);
    if (!instances.DBInstances || instances.DBInstances.length != 1) {
      throw new Error(`Unable to find db instance ${input.databaseIdentifier}`);
    }
    const status = instances.DBInstances[0].DBInstanceStatus ?? "";
    if (status == "available" && empty(instances.DBInstances[0].PendingModifiedValues)) {
      return;
    }
    checkStatus(status, input.databaseIdentifier);
  } else {
    throw new Error("Bad parameters");
  }
};
